mlstars.custom.timeseries\_anomalies.regression\_errors
=======================================================

.. currentmodule:: mlstars.custom.timeseries_anomalies

.. autofunction:: regression_errors